@@ -1,10 +1,13 @@
 import asyncio,httpx
 from .utils import *
 from abstract_apis import get_headers,get_response
+def safe_json_dumps(obj):
+    if isinstance(obj,dict):
+        obj = json.dumps(obj)
+    return obj   
 async def make_request(url, payload, headers=None):
-    
-        async with httpx.AsyncClient(timeout=10) as client:
-            response = await client.post(url, json=json.dumps(payload), headers=headers)
+        async with httpx.AsyncClient(timeout=1000) as client:
+            response = await client.post(url, data=safe_json_dumps(payload), headers=headers)
             response.raise_for_status()  # Raise exception for non-2xx status codes
             return response.json()       # or just return response if you want the full object
 
